// Load node modules.
const path = require('path')

// Determine the location of the closest package configuration.
const findConfig = require('find-config')
const packageConfigPath = findConfig('package.json', { cwd: path.resolve(__dirname, '..') })
if (packageConfigPath === null) {
	throw new Error("Cannot find the project's package configuration.")
}

// A flag that stores whether the path alias was set.
let isSetup = false

// Expose the function that sets the path alias.
module.exports = (modulePathAlias) => {
	// Verify that the path alias isn't already set.
	if (isSetup) {
		return
	}

	// Validate the submitted path alias.
	if ((typeof modulePathAlias !== 'string') || (modulePathAlias === '')) {
		throw new Error('The submitted path alias must be a non-empty string.')
	}

	// Setup module-alias to properly load non-relative local modules.
	const moduleAlias = require('module-alias')
	moduleAlias.addAlias(modulePathAlias, path.dirname(packageConfigPath))

	// Set the flag to forbid further calls of the function.
	isSetup = true
}
